@@ -193,20 +193,18 @@ impl<'a> Compiler<'a> {
         }
 
         for (il, lane) in lanes {
-            {
-                let nodeid = NodeId {
-                    lane: il as u16,
-                    pos: 0,
-                };
-                let nodeid_hash = Handle::from_u32(nodeid.into());
-                let handle = u32::try_from(self.program.bytecode.len())
-                    .expect("bytecode length to fit into 32 bits");
-                self.program
-                    .labels
-                    .0
-                    .insert(nodeid_hash, Label::new(handle))
-                    .unwrap();
-            }
+            let nodeid = NodeId {
+                lane: il as u16,
+                pos: 0,
+            };
+            let nodeid_hash = Handle::from_u32(nodeid.into());
+            let handle = u32::try_from(self.program.bytecode.len())
+                .expect("bytecode length to fit into 32 bits");
+            self.program
+                .labels
+                .0
+                .insert(nodeid_hash, Label::new(handle))
+                .unwrap();
 
             self.scope_begin();
 
@@ -241,6 +239,7 @@ impl<'a> Compiler<'a> {
         }
     }
 
+    /// add a local variable
     fn add_local(&mut self, name: VarName) -> CompilationResult<()> {
         self.validate_var_name(&name)?;
         self.locals
@@ -420,7 +419,7 @@ impl<'a> Compiler<'a> {
                 self.program
                     .variables
                     .names
-                    .entry(*id)
+                    .entry(Handle::from_u32(id.0))
                     .or_insert_with(move || *variable.0);
                 write_to_vec(*id, &mut self.program.bytecode);
             }
@@ -519,7 +518,7 @@ impl<'a> Compiler<'a> {
             self.program
                 .variables
                 .names
-                .entry(id)
+                .entry(Handle::from_u32(id.0))
                 .or_insert_with(|| *variable.0);
             self.push_instruction(Instruction::ReadGlobalVar);
             write_to_vec(id, &mut self.program.bytecode);
